@@ -64,6 +64,10 @@ new LambdaToDynamoDB(scope: Construct, id: string, props: LambdaToDynamoDBProps)
 |dynamoTableProps?|[`dynamodb.TableProps`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-dynamodb.TableProps.html)|Optional user provided props to override the default props for DynamoDB Table|
 |existingTableObj?|[`dynamodb.Table`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-dynamodb.Table.html)|Existing instance of DynamoDB table object, If this is set then the dynamoTableProps is ignored|
 |tablePermissions?|`string`|Optional table permissions to grant to the Lambda function. One of the following may be specified: `All`, `Read`, `ReadWrite`, `Write`.|
+|tableEnvironmentVariableName?|`string`|Optional Name for the DynamoDB table environment variable set for the Lambda function.|
+|existingVpc?|[`ec2.IVpc`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-ec2.IVpc.html)|An optional, existing VPC into which this pattern should be deployed. When deployed in a VPC, the Lambda function will use ENIs in the VPC to access network resources and a Gateway Endpoint will be created in the VPC for Amazon DynamoDB. If an existing VPC is provided, the `deployVpc` property cannot be `true`. This uses `ec2.IVpc` to allow clients to supply VPCs that exist outside the stack using the [`ec2.Vpc.fromLookup()`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-ec2.Vpc.html#static-fromwbrlookupscope-id-options) method.|
+|vpcProps?|[`ec2.VpcProps`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-ec2.VpcProps.html)|Optional user-provided properties to override the default properties for the new VPC. `enableDnsHostnames`, `enableDnsSupport`, `natGateways` and `subnetConfiguration` are set by the pattern, so any values for those properties supplied here will be overrriden. If `deployVpc` is not `true` then this property will be ignored.|
+|deployVpc?|`boolean`|Whether to create a new VPC based on `vpcProps` into which to deploy this pattern. Setting this to true will deploy the minimal, most private VPC to run the pattern:<ul><li> One isolated subnet in each Availability Zone used by the CDK program</li><li>`enableDnsHostnames` and `enableDnsSupport` will both be set to true</li></ul>If this property is `true` then `existingVpc` cannot be specified. Defaults to `false`.|
 
 ## Pattern Properties
 
@@ -71,6 +75,7 @@ new LambdaToDynamoDB(scope: Construct, id: string, props: LambdaToDynamoDBProps)
 |:-------------|:----------------|-----------------|
 |lambdaFunction|[`lambda.Function`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-lambda.Function.html)|Returns an instance of lambda.Function created by the construct|
 |dynamoTable|[`dynamodb.Table`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-dynamodb.Table.html)|Returns an instance of dynamodb.Table created by the construct|
+|vpc?|[`ec2.IVpc`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-ec2.IVpc.html)|Returns an interface on the VPC used by the pattern (if any). This may be a VPC created by the pattern or the VPC supplied to the pattern constructor.|
 
 ## Default settings
 
@@ -83,7 +88,7 @@ Out of the box implementation of the Construct without any override will set the
 * Enable X-Ray Tracing
 * Set Environment Variables
 
-  * DDB_TABLE_NAME
+  * (default) DDB_TABLE_NAME
   * AWS_NODEJS_CONNECTION_REUSE_ENABLED (for Node 10.x and higher functions)
 
 ### Amazon DynamoDB Table
@@ -116,6 +121,7 @@ import typing_extensions
 from ._jsii import *
 
 import aws_cdk.aws_dynamodb
+import aws_cdk.aws_ec2
 import aws_cdk.aws_lambda
 import aws_cdk.core
 
@@ -130,31 +136,43 @@ class LambdaToDynamoDB(
         scope: aws_cdk.core.Construct,
         id: builtins.str,
         *,
+        deploy_vpc: typing.Optional[builtins.bool] = None,
         dynamo_table_props: typing.Optional[aws_cdk.aws_dynamodb.TableProps] = None,
         existing_lambda_obj: typing.Optional[aws_cdk.aws_lambda.Function] = None,
         existing_table_obj: typing.Optional[aws_cdk.aws_dynamodb.Table] = None,
+        existing_vpc: typing.Optional[aws_cdk.aws_ec2.IVpc] = None,
         lambda_function_props: typing.Optional[aws_cdk.aws_lambda.FunctionProps] = None,
+        table_environment_variable_name: typing.Optional[builtins.str] = None,
         table_permissions: typing.Optional[builtins.str] = None,
+        vpc_props: typing.Optional[aws_cdk.aws_ec2.VpcProps] = None,
     ) -> None:
         '''
         :param scope: - represents the scope for all the resources.
         :param id: - this is a a scope-unique id.
+        :param deploy_vpc: Whether to deploy a new VPC. Default: - false
         :param dynamo_table_props: Optional user provided props to override the default props. Default: - Default props are used
         :param existing_lambda_obj: Existing instance of Lambda Function object, if this is set then the lambdaFunctionProps is ignored. Default: - None
         :param existing_table_obj: Existing instance of DynamoDB table object, If this is set then the dynamoTableProps is ignored. Default: - None
+        :param existing_vpc: An existing VPC for the construct to use (construct will NOT create a new VPC in this case).
         :param lambda_function_props: User provided props to override the default props for the Lambda function. Default: - Default props are used
+        :param table_environment_variable_name: Optional Name for the DynamoDB table environment variable set for the Lambda function. Default: - None
         :param table_permissions: Optional table permissions to grant to the Lambda function. One of the following may be specified: "All", "Read", "ReadWrite", "Write". Default: - Read/write access is given to the Lambda function if no value is specified.
+        :param vpc_props: Properties to override default properties if deployVpc is true.
 
         :access: public
         :since: 0.8.0
         :summary: Constructs a new instance of the LambdaToDynamoDB class.
         '''
         props = LambdaToDynamoDBProps(
+            deploy_vpc=deploy_vpc,
             dynamo_table_props=dynamo_table_props,
             existing_lambda_obj=existing_lambda_obj,
             existing_table_obj=existing_table_obj,
+            existing_vpc=existing_vpc,
             lambda_function_props=lambda_function_props,
+            table_environment_variable_name=table_environment_variable_name,
             table_permissions=table_permissions,
+            vpc_props=vpc_props,
         )
 
         jsii.create(LambdaToDynamoDB, self, [scope, id, props])
@@ -169,34 +187,51 @@ class LambdaToDynamoDB(
     def lambda_function(self) -> aws_cdk.aws_lambda.Function:
         return typing.cast(aws_cdk.aws_lambda.Function, jsii.get(self, "lambdaFunction"))
 
+    @builtins.property # type: ignore[misc]
+    @jsii.member(jsii_name="vpc")
+    def vpc(self) -> typing.Optional[aws_cdk.aws_ec2.IVpc]:
+        return typing.cast(typing.Optional[aws_cdk.aws_ec2.IVpc], jsii.get(self, "vpc"))
+
 
 @jsii.data_type(
     jsii_type="@aws-solutions-constructs/aws-lambda-dynamodb.LambdaToDynamoDBProps",
     jsii_struct_bases=[],
     name_mapping={
+        "deploy_vpc": "deployVpc",
         "dynamo_table_props": "dynamoTableProps",
         "existing_lambda_obj": "existingLambdaObj",
         "existing_table_obj": "existingTableObj",
+        "existing_vpc": "existingVpc",
         "lambda_function_props": "lambdaFunctionProps",
+        "table_environment_variable_name": "tableEnvironmentVariableName",
         "table_permissions": "tablePermissions",
+        "vpc_props": "vpcProps",
     },
 )
 class LambdaToDynamoDBProps:
     def __init__(
         self,
         *,
+        deploy_vpc: typing.Optional[builtins.bool] = None,
         dynamo_table_props: typing.Optional[aws_cdk.aws_dynamodb.TableProps] = None,
         existing_lambda_obj: typing.Optional[aws_cdk.aws_lambda.Function] = None,
         existing_table_obj: typing.Optional[aws_cdk.aws_dynamodb.Table] = None,
+        existing_vpc: typing.Optional[aws_cdk.aws_ec2.IVpc] = None,
         lambda_function_props: typing.Optional[aws_cdk.aws_lambda.FunctionProps] = None,
+        table_environment_variable_name: typing.Optional[builtins.str] = None,
         table_permissions: typing.Optional[builtins.str] = None,
+        vpc_props: typing.Optional[aws_cdk.aws_ec2.VpcProps] = None,
     ) -> None:
         '''
+        :param deploy_vpc: Whether to deploy a new VPC. Default: - false
         :param dynamo_table_props: Optional user provided props to override the default props. Default: - Default props are used
         :param existing_lambda_obj: Existing instance of Lambda Function object, if this is set then the lambdaFunctionProps is ignored. Default: - None
         :param existing_table_obj: Existing instance of DynamoDB table object, If this is set then the dynamoTableProps is ignored. Default: - None
+        :param existing_vpc: An existing VPC for the construct to use (construct will NOT create a new VPC in this case).
         :param lambda_function_props: User provided props to override the default props for the Lambda function. Default: - Default props are used
+        :param table_environment_variable_name: Optional Name for the DynamoDB table environment variable set for the Lambda function. Default: - None
         :param table_permissions: Optional table permissions to grant to the Lambda function. One of the following may be specified: "All", "Read", "ReadWrite", "Write". Default: - Read/write access is given to the Lambda function if no value is specified.
+        :param vpc_props: Properties to override default properties if deployVpc is true.
 
         :summary: The properties for the LambdaToDynamoDB Construct
         '''
@@ -204,17 +239,36 @@ class LambdaToDynamoDBProps:
             dynamo_table_props = aws_cdk.aws_dynamodb.TableProps(**dynamo_table_props)
         if isinstance(lambda_function_props, dict):
             lambda_function_props = aws_cdk.aws_lambda.FunctionProps(**lambda_function_props)
+        if isinstance(vpc_props, dict):
+            vpc_props = aws_cdk.aws_ec2.VpcProps(**vpc_props)
         self._values: typing.Dict[str, typing.Any] = {}
+        if deploy_vpc is not None:
+            self._values["deploy_vpc"] = deploy_vpc
         if dynamo_table_props is not None:
             self._values["dynamo_table_props"] = dynamo_table_props
         if existing_lambda_obj is not None:
             self._values["existing_lambda_obj"] = existing_lambda_obj
         if existing_table_obj is not None:
             self._values["existing_table_obj"] = existing_table_obj
+        if existing_vpc is not None:
+            self._values["existing_vpc"] = existing_vpc
         if lambda_function_props is not None:
             self._values["lambda_function_props"] = lambda_function_props
+        if table_environment_variable_name is not None:
+            self._values["table_environment_variable_name"] = table_environment_variable_name
         if table_permissions is not None:
             self._values["table_permissions"] = table_permissions
+        if vpc_props is not None:
+            self._values["vpc_props"] = vpc_props
+
+    @builtins.property
+    def deploy_vpc(self) -> typing.Optional[builtins.bool]:
+        '''Whether to deploy a new VPC.
+
+        :default: - false
+        '''
+        result = self._values.get("deploy_vpc")
+        return typing.cast(typing.Optional[builtins.bool], result)
 
     @builtins.property
     def dynamo_table_props(self) -> typing.Optional[aws_cdk.aws_dynamodb.TableProps]:
@@ -243,6 +297,12 @@ class LambdaToDynamoDBProps:
         result = self._values.get("existing_table_obj")
         return typing.cast(typing.Optional[aws_cdk.aws_dynamodb.Table], result)
 
+    @builtins.property
+    def existing_vpc(self) -> typing.Optional[aws_cdk.aws_ec2.IVpc]:
+        '''An existing VPC for the construct to use (construct will NOT create a new VPC in this case).'''
+        result = self._values.get("existing_vpc")
+        return typing.cast(typing.Optional[aws_cdk.aws_ec2.IVpc], result)
+
     @builtins.property
     def lambda_function_props(
         self,
@@ -254,6 +314,15 @@ class LambdaToDynamoDBProps:
         result = self._values.get("lambda_function_props")
         return typing.cast(typing.Optional[aws_cdk.aws_lambda.FunctionProps], result)
 
+    @builtins.property
+    def table_environment_variable_name(self) -> typing.Optional[builtins.str]:
+        '''Optional Name for the DynamoDB table environment variable set for the Lambda function.
+
+        :default: - None
+        '''
+        result = self._values.get("table_environment_variable_name")
+        return typing.cast(typing.Optional[builtins.str], result)
+
     @builtins.property
     def table_permissions(self) -> typing.Optional[builtins.str]:
         '''Optional table permissions to grant to the Lambda function.
@@ -265,6 +334,12 @@ class LambdaToDynamoDBProps:
         result = self._values.get("table_permissions")
         return typing.cast(typing.Optional[builtins.str], result)
 
+    @builtins.property
+    def vpc_props(self) -> typing.Optional[aws_cdk.aws_ec2.VpcProps]:
+        '''Properties to override default properties if deployVpc is true.'''
+        result = self._values.get("vpc_props")
+        return typing.cast(typing.Optional[aws_cdk.aws_ec2.VpcProps], result)
+
     def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
 
